"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryExtendedFields = exports.deleteExtendedField = exports.updateExtendedField = exports.getExtendedField = exports.findOrCreateExtendedField = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const timestamp_2 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixpressContactsFieldsV4ContactExtendedFieldsServiceV4Url(opts) {
    const domainToMappings = {
        'www.wixapis.com': [
            {
                srcPath: '/contacts/v4/extended-fields',
                destPath: '/v4/extended-fields',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/contacts/v4/extended-fields',
                destPath: '/v4/extended-fields',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/contacts/v4/extended-fields',
                destPath: '/v4/extended-fields',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/contacts/v4/extended-fields',
                destPath: '/v4/extended-fields',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/contacts/v4/extended-fields',
                destPath: '/v4/extended-fields',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/contacts/v4/extended-fields',
                destPath: '/v4/extended-fields',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/crm_extended-fields';
/**
 * Retrieves a custom field with a specified name, or creates one if it doesn't exist.
 * The number of custom fields is limited to 100.
 *
 * Successful calls to this method always return a field,
 * which can be specified in subsequent calls.
 *
 * To find an existing custom field without potentially creating a new one, call Get Extended Field or
 * Query Extended Fields.
 */
function findOrCreateExtendedField(payload) {
    function __findOrCreateExtendedField({ host }) {
        const metadata = {
            entityFqdn: 'wix.contacts.v4.extended_field',
            method: 'POST',
            methodFqn: 'com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.FindOrCreateExtendedField',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressContactsFieldsV4ContactExtendedFieldsServiceV4Url({
                protoPath: '/v4/extended-fields',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'field.createdDate' },
                        { path: 'field.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __findOrCreateExtendedField;
}
exports.findOrCreateExtendedField = findOrCreateExtendedField;
/** Retrieves an extended field by the specified extended field key. */
function getExtendedField(payload) {
    function __getExtendedField({ host }) {
        const metadata = {
            entityFqdn: 'wix.contacts.v4.extended_field',
            method: 'GET',
            methodFqn: 'com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.GetExtendedField',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressContactsFieldsV4ContactExtendedFieldsServiceV4Url({
                protoPath: '/v4/extended-fields/{key}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'field.createdDate' },
                        { path: 'field.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getExtendedField;
}
exports.getExtendedField = getExtendedField;
/** Renames an extended field. */
function updateExtendedField(payload) {
    function __updateExtendedField({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'field.createdDate' }, { path: 'field.updatedDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.contacts.v4.extended_field',
            method: 'PATCH',
            methodFqn: 'com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.UpdateExtendedField',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressContactsFieldsV4ContactExtendedFieldsServiceV4Url({
                protoPath: '/v4/extended-fields/{field.key}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'field.createdDate' },
                        { path: 'field.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateExtendedField;
}
exports.updateExtendedField = updateExtendedField;
/**
 * Deletes an extended field.
 *
 * When an extended field is deleted,
 * any contact data stored in the field is also permanently deleted.
 */
function deleteExtendedField(payload) {
    function __deleteExtendedField({ host }) {
        const metadata = {
            entityFqdn: 'wix.contacts.v4.extended_field',
            method: 'DELETE',
            methodFqn: 'com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.DeleteExtendedField',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressContactsFieldsV4ContactExtendedFieldsServiceV4Url({
                protoPath: '/v4/extended-fields/{key}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deleteExtendedField;
}
exports.deleteExtendedField = deleteExtendedField;
/**
 * Creates a query to retrieve a list of extended fields.
 *
 * The `queryExtendedFields()` method builds a query to retrieve a list of extended fields and returns an `FieldsQueryBuilder` object.
 *
 * The returned object contains the query definition, which is used to run the query using the `find()` method.
 *
 * You can refine the query by chaining `FieldsQueryBuilder` methods onto the query. `FieldsQueryBuilder` methods enable you to filter, sort, and control the results that `queryExtendedFields()` returns.
 *
 * `queryExtendedFields()` runs with these `FieldsQueryBuilder` defaults, which you can override:
 * - `skip()`
 * - `limit(50)`
 * - `descending('_createdDate')`
 *
 * The following `FieldsQueryBuilder` methods are supported for `queryExtendedFields()`. For a full description of the `Extended Field` object, see the object returned for the `items` property in `FieldsQueryResult`.
 */
function queryExtendedFields(payload) {
    function __queryExtendedFields({ host }) {
        const metadata = {
            entityFqdn: 'wix.contacts.v4.extended_field',
            method: 'POST',
            methodFqn: 'com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.QueryExtendedFields',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressContactsFieldsV4ContactExtendedFieldsServiceV4Url({
                protoPath: '/v4/extended-fields/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'fields.createdDate' },
                        { path: 'fields.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __queryExtendedFields;
}
exports.queryExtendedFields = queryExtendedFields;
//# sourceMappingURL=contacts-v4-extended-field-extended-fields.http.js.map