"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryExtendedFields = exports.deleteExtendedField = exports.renameExtendedField = exports.getExtendedField = exports.findOrCreateExtendedField = exports.WebhookIdentityType = exports.SortOrder = exports.FieldType = exports.FieldDataType = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const query_builder_1 = require("@wix/sdk-runtime/query-builder");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixContactsV4ExtendedField = __importStar(require("./contacts-v4-extended-field-extended-fields.http.js"));
var FieldDataType;
(function (FieldDataType) {
    /** Accepts strings. */
    FieldDataType["TEXT"] = "TEXT";
    /** Accepts floats. */
    FieldDataType["NUMBER"] = "NUMBER";
    /** Accepts dates formatted as `YYYY-MM-DD`. */
    FieldDataType["DATE"] = "DATE";
    /** Accepts strings. Prepends `https://` if no protocol is included. */
    FieldDataType["URL"] = "URL";
})(FieldDataType || (exports.FieldDataType = FieldDataType = {}));
var FieldType;
(function (FieldType) {
    /** Field is a system field managed by Wix. System fields can't be modified by calling the Update Extended Field method. */
    FieldType["SYSTEM"] = "SYSTEM";
    /** Field is a custom field and can be modified by calling the Update Extended Field method. */
    FieldType["USER_DEFINED"] = "USER_DEFINED";
})(FieldType || (exports.FieldType = FieldType = {}));
var SortOrder;
(function (SortOrder) {
    /** Sort by ascending order. */
    SortOrder["ASC"] = "ASC";
    /** Sort by descending order. */
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Retrieves a custom field with a specified name, or creates one if it doesn't exist.
 * The number of custom fields is limited to 100.
 *
 * Successful calls to this method always return a field,
 * which can be specified in subsequent calls.
 *
 * To find an existing custom field without potentially creating a new one, call Get Extended Field or
 * Query Extended Fields.
 * @param displayName - Display name to retrieve or create.
 *
 * If an existing custom field is an exact match
 * for the specified display name,
 * the existing field is returned.
 * If not, a new field is created and returned.
 * @param dataType - Type of data the field holds.
 * Ignored if an existing field is an exact match
 * for the specified display name.
 * @public
 * @requiredField dataType
 * @requiredField displayName
 * @permissionId CONTACTS_SCHEMA.MODIFY
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @returns Extended field that was found or created.
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.FindOrCreateExtendedField
 */
async function findOrCreateExtendedField(displayName, dataType) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        displayName: displayName,
        dataType: dataType,
    });
    const reqOpts = ambassadorWixContactsV4ExtendedField.findOrCreateExtendedField(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { displayName: '$[0]', dataType: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['displayName', 'dataType']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.findOrCreateExtendedField = findOrCreateExtendedField;
/**
 * Retrieves an extended field by the specified extended field key.
 * @public
 * @requiredField key
 * @param key - null
 * @permissionId CONTACTS_SCHEMA.VIEW
 * @permissionScope Manage Bookings Services and Settings
 * @permissionScopeId SCOPE.BOOKINGS.CONFIGURATION
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @returns The specified field.
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.GetExtendedField
 */
async function getExtendedField(key) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ key: key });
    const reqOpts = ambassadorWixContactsV4ExtendedField.getExtendedField(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.field;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { key: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['key']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getExtendedField = getExtendedField;
/**
 * Renames an extended field.
 * @public
 * @requiredField field
 * @requiredField field.displayName
 * @requiredField key
 * @param key - null
 * @param field - null
 * @permissionId CONTACTS_SCHEMA.MODIFY
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @returns Renamed extended field.
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.UpdateExtendedField
 */
async function renameExtendedField(key, field) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        field: { ...field, key: key },
    });
    const reqOpts = ambassadorWixContactsV4ExtendedField.updateExtendedField(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.field;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: { field: '$[1]' },
            explicitPathsToArguments: { 'field.key': '$[0]' },
            singleArgumentUnchanged: false,
        }, ['key', 'field']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.renameExtendedField = renameExtendedField;
/**
 * Deletes an extended field.
 *
 * When an extended field is deleted,
 * any contact data stored in the field is also permanently deleted.
 * @param key - Extended field key.
 * @public
 * @requiredField key
 * @permissionId CONTACTS_SCHEMA.MODIFY
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.DeleteExtendedField
 */
async function deleteExtendedField(key) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ key: key });
    const reqOpts = ambassadorWixContactsV4ExtendedField.deleteExtendedField(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { key: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['key']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.deleteExtendedField = deleteExtendedField;
/**
 * Creates a query to retrieve a list of extended fields.
 *
 * The `queryExtendedFields()` method builds a query to retrieve a list of extended fields and returns an `FieldsQueryBuilder` object.
 *
 * The returned object contains the query definition, which is used to run the query using the `find()` method.
 *
 * You can refine the query by chaining `FieldsQueryBuilder` methods onto the query. `FieldsQueryBuilder` methods enable you to filter, sort, and control the results that `queryExtendedFields()` returns.
 *
 * `queryExtendedFields()` runs with these `FieldsQueryBuilder` defaults, which you can override:
 * - `skip()`
 * - `limit(50)`
 * - `descending('_createdDate')`
 *
 * The following `FieldsQueryBuilder` methods are supported for `queryExtendedFields()`. For a full description of the `Extended Field` object, see the object returned for the `items` property in `FieldsQueryResult`.
 * @public
 * @permissionScope Manage Bookings Services and Settings
 * @permissionScopeId SCOPE.BOOKINGS.CONFIGURATION
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @permissionScope Manage Contact Extended Fields
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-EX-FIELDS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @permissionId CONTACTS_SCHEMA.VIEW
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.fields.v4.ContactExtendedFieldsServiceV4.QueryExtendedFields
 */
function queryExtendedFields() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    return (0, query_builder_1.queryBuilder)({
        func: async (payload) => {
            const reqOpts = ambassadorWixContactsV4ExtendedField.queryExtendedFields(payload);
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, {}];
            return (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data, }) => {
            const transformedData = (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(data);
            return {
                items: transformedData?.fields,
                pagingMetadata: transformedData?.pagingMetadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = (0, transform_error_1.transformError)(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'OFFSET',
        transformationPaths: {},
    });
}
exports.queryExtendedFields = queryExtendedFields;
//# sourceMappingURL=contacts-v4-extended-field-extended-fields.universal.js.map