import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Retrieves a custom field with a specified name, or creates one if it doesn't exist.
 * The number of custom fields is limited to 100.
 *
 * Successful calls to this method always return a field,
 * which can be specified in subsequent calls.
 *
 * To find an existing custom field without potentially creating a new one, call Get Extended Field or
 * Query Extended Fields.
 */
export declare function findOrCreateExtendedField(payload: object): RequestOptionsFactory<any>;
/** Retrieves an extended field by the specified extended field key. */
export declare function getExtendedField(payload: object): RequestOptionsFactory<any>;
/** Renames an extended field. */
export declare function updateExtendedField(payload: object): RequestOptionsFactory<any>;
/**
 * Deletes an extended field.
 *
 * When an extended field is deleted,
 * any contact data stored in the field is also permanently deleted.
 */
export declare function deleteExtendedField(payload: object): RequestOptionsFactory<any>;
/**
 * Creates a query to retrieve a list of extended fields.
 *
 * The `queryExtendedFields()` method builds a query to retrieve a list of extended fields and returns an `FieldsQueryBuilder` object.
 *
 * The returned object contains the query definition, which is used to run the query using the `find()` method.
 *
 * You can refine the query by chaining `FieldsQueryBuilder` methods onto the query. `FieldsQueryBuilder` methods enable you to filter, sort, and control the results that `queryExtendedFields()` returns.
 *
 * `queryExtendedFields()` runs with these `FieldsQueryBuilder` defaults, which you can override:
 * - `skip()`
 * - `limit(50)`
 * - `descending('_createdDate')`
 *
 * The following `FieldsQueryBuilder` methods are supported for `queryExtendedFields()`. For a full description of the `Extended Field` object, see the object returned for the `items` property in `FieldsQueryResult`.
 */
export declare function queryExtendedFields(payload: object): RequestOptionsFactory<any>;
