import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { ExtendedField, ExtendedFieldCreatedEnvelope, ExtendedFieldDeletedEnvelope, ExtendedFieldNonNullableFields, ExtendedFieldUpdatedEnvelope, FieldDataType, FieldsQueryBuilder, FindOrCreateExtendedFieldResponse, FindOrCreateExtendedFieldResponseNonNullableFields, RenameExtendedField } from './contacts-v4-extended-field-extended-fields.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function findOrCreateExtendedField(httpClient: HttpClient): FindOrCreateExtendedFieldSignature;
interface FindOrCreateExtendedFieldSignature {
    /**
     * Retrieves a custom field with a specified name, or creates one if it doesn't exist.
     * The number of custom fields is limited to 100.
     *
     * Successful calls to this method always return a field,
     * which can be specified in subsequent calls.
     *
     * To find an existing custom field without potentially creating a new one, call Get Extended Field or
     * Query Extended Fields.
     * @param - Display name to retrieve or create.
     *
     * If an existing custom field is an exact match
     * for the specified display name,
     * the existing field is returned.
     * If not, a new field is created and returned.
     * @param - Type of data the field holds.
     * Ignored if an existing field is an exact match
     * for the specified display name.
     * @returns Extended field that was found or created.
     */
    (displayName: string, dataType: FieldDataType): Promise<FindOrCreateExtendedFieldResponse & FindOrCreateExtendedFieldResponseNonNullableFields>;
}
export declare function getExtendedField(httpClient: HttpClient): GetExtendedFieldSignature;
interface GetExtendedFieldSignature {
    /**
     * Retrieves an extended field by the specified extended field key.
     * @param - null
     * @returns The specified field.
     */
    (key: string): Promise<ExtendedField & ExtendedFieldNonNullableFields>;
}
export declare function renameExtendedField(httpClient: HttpClient): RenameExtendedFieldSignature;
interface RenameExtendedFieldSignature {
    /**
     * Renames an extended field.
     * @param - null
     * @param - null
     * @returns Renamed extended field.
     */
    (key: string, field: RenameExtendedField): Promise<ExtendedField & ExtendedFieldNonNullableFields>;
}
export declare function deleteExtendedField(httpClient: HttpClient): DeleteExtendedFieldSignature;
interface DeleteExtendedFieldSignature {
    /**
     * Deletes an extended field.
     *
     * When an extended field is deleted,
     * any contact data stored in the field is also permanently deleted.
     * @param - Extended field key.
     */
    (key: string): Promise<void>;
}
export declare function queryExtendedFields(httpClient: HttpClient): QueryExtendedFieldsSignature;
interface QueryExtendedFieldsSignature {
    /**
     * Creates a query to retrieve a list of extended fields.
     *
     * The `queryExtendedFields()` method builds a query to retrieve a list of extended fields and returns an `FieldsQueryBuilder` object.
     *
     * The returned object contains the query definition, which is used to run the query using the `find()` method.
     *
     * You can refine the query by chaining `FieldsQueryBuilder` methods onto the query. `FieldsQueryBuilder` methods enable you to filter, sort, and control the results that `queryExtendedFields()` returns.
     *
     * `queryExtendedFields()` runs with these `FieldsQueryBuilder` defaults, which you can override:
     * - `skip()`
     * - `limit(50)`
     * - `descending('_createdDate')`
     *
     * The following `FieldsQueryBuilder` methods are supported for `queryExtendedFields()`. For a full description of the `Extended Field` object, see the object returned for the `items` property in `FieldsQueryResult`.
     */
    (): FieldsQueryBuilder;
}
export declare const onExtendedFieldCreated: EventDefinition<ExtendedFieldCreatedEnvelope, "wix.contacts.v4.extended-field_created">;
export declare const onExtendedFieldDeleted: EventDefinition<ExtendedFieldDeletedEnvelope, "wix.contacts.v4.extended-field_deleted">;
export declare const onExtendedFieldUpdated: EventDefinition<ExtendedFieldUpdatedEnvelope, "wix.contacts.v4.extended-field_updated">;
export { ActionEvent, BaseEventMetadata, DeleteExtendedFieldRequest, DeleteExtendedFieldResponse, DomainEvent, DomainEventBodyOneOf, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, ExtendedField, ExtendedFieldCreatedEnvelope, ExtendedFieldDeletedEnvelope, ExtendedFieldNonNullableFields, ExtendedFieldUpdatedEnvelope, FieldDataType, FieldType, FieldsQueryBuilder, FieldsQueryResult, FindOrCreateExtendedFieldRequest, FindOrCreateExtendedFieldResponse, FindOrCreateExtendedFieldResponseNonNullableFields, GdprListRequest, GdprListResponse, GetExtendedFieldByLegacyIdRequest, GetExtendedFieldByLegacyIdResponse, GetExtendedFieldRequest, GetExtendedFieldResponse, GetExtendedFieldResponseNonNullableFields, IdentificationData, IdentificationDataIdOneOf, ListExtendedFieldsRequest, ListExtendedFieldsResponse, MessageEnvelope, Paging, PagingMetadata, PurgeRequest, PurgeResponse, Query, QueryExtendedFieldsRequest, QueryExtendedFieldsResponse, QueryExtendedFieldsResponseNonNullableFields, RenameExtendedField, RestoreInfo, SortOrder, Sorting, UpdateExtendedFieldRequest, UpdateExtendedFieldResponse, UpdateExtendedFieldResponseNonNullableFields, WebhookIdentityType, } from './contacts-v4-extended-field-extended-fields.universal.js';
